@@ -4,7 +4,7 @@
 # LICENSE file in the root directory of this source tree.
 import pathlib
 import warnings
-from typing import List, Optional, Sequence, Sized, Tuple, Union
+from typing import List, Optional, Sequence, Sized, Tuple, Type, Union
 
 import numpy as np
 
@@ -299,10 +299,11 @@ class ReplayBuffer:
     Args:
         capacity (int): the maximum number of transitions that the buffer can store.
             When the capacity is reached, the contents are overwritten in FIFO fashion.
-        obs_shape (tuple of ints): the shape of the observations to store.
-        action_shape (tuple of ints): the shape of the actions to store.
+        obs_shape (Sequence of ints): the shape of the observations to store.
+        action_shape (Sequence of ints): the shape of the actions to store.
         obs_type (type): the data type of the observations (defaults to np.float32).
         action_type (type): the data type of the actions (defaults to np.float32).
+        reward_type (type): the data type of the rewards (defaults to np.float32).
         rng (np.random.Generator, optional): a random number generator when sampling
             batches. If None (default value), a new default generator will be used.
         max_trajectory_length (int, optional): if given, indicates that trajectory
@@ -319,10 +320,11 @@ class ReplayBuffer:
     def __init__(
         self,
         capacity: int,
-        obs_shape: Tuple[int],
-        action_shape: Tuple[int],
-        obs_type=np.float32,
-        action_type=np.float32,
+        obs_shape: Sequence[int],
+        action_shape: Sequence[int],
+        obs_type: Type = np.float32,
+        action_type: Type = np.float32,
+        reward_type: Type = np.float32,
         rng: Optional[np.random.Generator] = None,
         max_trajectory_length: Optional[int] = None,
     ):
@@ -338,7 +340,7 @@ class ReplayBuffer:
         self.obs = np.empty((capacity, *obs_shape), dtype=obs_type)
         self.next_obs = np.empty((capacity, *obs_shape), dtype=obs_type)
         self.action = np.empty((capacity, *action_shape), dtype=action_type)
-        self.reward = np.empty(capacity, dtype=np.float32)
+        self.reward = np.empty(capacity, dtype=reward_type)
         self.done = np.empty(capacity, dtype=bool)
 
         if rng is None:
@@ -349,7 +351,7 @@ class ReplayBuffer:
         self._start_last_trajectory = 0
 
     @property
-    def stores_trajectories(self):
+    def stores_trajectories(self) -> bool:
         return self.trajectory_indices is not None
 
     @staticmethod
@@ -434,7 +436,7 @@ class ReplayBuffer:
             self.cur_idx = (self.cur_idx + 1) % self.capacity
             self.num_stored = min(self.num_stored + 1, self.capacity)
 
-    def sample(self, batch_size: int) -> Sized:
+    def sample(self, batch_size: int) -> TransitionBatch:
         """Samples a batch of transitions from the replay buffer.
 
         Args:
@@ -564,7 +566,7 @@ class ReplayBuffer:
             self,
             batch_size,
             val_ratio,
-            ensemble_size,
+            1 if ensemble_size is None else ensemble_size,
             shuffle_each_epoch,
             bootstrap_permutes,
         )
